#include "DrawingManager.h"

#include "INativeDrawingContext.h"
#include "DrawingSurface.h"
#include "DrawingContext.h"
#ifdef __linux__
#include "CairoInterface.h"
#endif

DrawingManager::DrawingManager()
{
#ifdef __linux__
    mCairoInterface = CairoInterface::Create();
#endif
}

std::unique_ptr<DrawingManager> DrawingManager::Create()
{
    return std::make_unique<DrawingManager>();
}

void DrawingManager::InitalizeSurface(unsigned width, unsigned height)
{
    mDrawingSurface = DrawingSurface::Create();
    mDrawingSurface->SetSize(width, height);
#ifdef __linux__
    if (mCairoInterface)
    {
        mCairoInterface->InitializeSurface(mDrawingSurface.get());
    }
#endif
}

void DrawingManager::InitializeContext()
{
    mDrawingContext = DrawingContext::Create();
#ifdef __linux__
    if (mCairoInterface && mDrawingSurface)
    {
        mCairoInterface->InitializeContext(mDrawingContext.get(), mDrawingSurface.get());
    }
#endif
}

void DrawingManager::AddText(TextElement* text)
{
    if (!mDrawingContext)
    {
        InitializeContext();
    }

    if (!mDrawingContext)
    {
        return;
    }
#ifdef __linux__
    if (mCairoInterface)
    {
        mCairoInterface->AddText(text, mDrawingContext.get());
    }
#endif
}

void DrawingManager::RenderToFile(const std::string& path)
{
#ifdef __linux__
    if (mDrawingSurface && mCairoInterface)
    {
        mCairoInterface->RenderToFile(mDrawingSurface.get(), path);
    }
#endif
}
